# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Session History Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.models_alliance_rule import ModelsAllianceRule
from ..models.models_matching_rule import ModelsMatchingRule


class ApimodelsXRayTicketObservabilityRequest(Model):
    """Apimodels X ray ticket observability request (apimodels.XRayTicketObservabilityRequest)

    Properties:
        action: (action) REQUIRED str

        game_mode: (gameMode) REQUIRED str

        is_backfill_match: (isBackfillMatch) REQUIRED bool

        is_rule_set_flexed: (isRuleSetFlexed) REQUIRED bool

        namespace: (namespace) REQUIRED str

        session_tick_id: (sessionTickID) REQUIRED str

        tick_id: (tickID) REQUIRED int

        ticket_id: (ticketID) REQUIRED str

        timestamp: (timestamp) REQUIRED str

        active_alliance_rule: (activeAllianceRule) OPTIONAL ModelsAllianceRule

        active_matching_rule: (activeMatchingRule) OPTIONAL List[ModelsMatchingRule]

        function: (function) OPTIONAL str

        iteration: (iteration) OPTIONAL int

        match_id: (matchID) OPTIONAL str

        remaining_players_per_ticket: (remainingPlayersPerTicket) OPTIONAL List[int]

        remaining_tickets: (remainingTickets) OPTIONAL int

        time_to_match_sec: (timeToMatchSec) OPTIONAL float

        unbackfill_reason: (unbackfillReason) OPTIONAL str

        unmatch_reason: (unmatchReason) OPTIONAL str
    """

    # region fields

    action: str  # REQUIRED
    game_mode: str  # REQUIRED
    is_backfill_match: bool  # REQUIRED
    is_rule_set_flexed: bool  # REQUIRED
    namespace: str  # REQUIRED
    session_tick_id: str  # REQUIRED
    tick_id: int  # REQUIRED
    ticket_id: str  # REQUIRED
    timestamp: str  # REQUIRED
    active_alliance_rule: ModelsAllianceRule  # OPTIONAL
    active_matching_rule: List[ModelsMatchingRule]  # OPTIONAL
    function: str  # OPTIONAL
    iteration: int  # OPTIONAL
    match_id: str  # OPTIONAL
    remaining_players_per_ticket: List[int]  # OPTIONAL
    remaining_tickets: int  # OPTIONAL
    time_to_match_sec: float  # OPTIONAL
    unbackfill_reason: str  # OPTIONAL
    unmatch_reason: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_action(self, value: str) -> ApimodelsXRayTicketObservabilityRequest:
        self.action = value
        return self

    def with_game_mode(self, value: str) -> ApimodelsXRayTicketObservabilityRequest:
        self.game_mode = value
        return self

    def with_is_backfill_match(
        self, value: bool
    ) -> ApimodelsXRayTicketObservabilityRequest:
        self.is_backfill_match = value
        return self

    def with_is_rule_set_flexed(
        self, value: bool
    ) -> ApimodelsXRayTicketObservabilityRequest:
        self.is_rule_set_flexed = value
        return self

    def with_namespace(self, value: str) -> ApimodelsXRayTicketObservabilityRequest:
        self.namespace = value
        return self

    def with_session_tick_id(
        self, value: str
    ) -> ApimodelsXRayTicketObservabilityRequest:
        self.session_tick_id = value
        return self

    def with_tick_id(self, value: int) -> ApimodelsXRayTicketObservabilityRequest:
        self.tick_id = value
        return self

    def with_ticket_id(self, value: str) -> ApimodelsXRayTicketObservabilityRequest:
        self.ticket_id = value
        return self

    def with_timestamp(self, value: str) -> ApimodelsXRayTicketObservabilityRequest:
        self.timestamp = value
        return self

    def with_active_alliance_rule(
        self, value: ModelsAllianceRule
    ) -> ApimodelsXRayTicketObservabilityRequest:
        self.active_alliance_rule = value
        return self

    def with_active_matching_rule(
        self, value: List[ModelsMatchingRule]
    ) -> ApimodelsXRayTicketObservabilityRequest:
        self.active_matching_rule = value
        return self

    def with_function(self, value: str) -> ApimodelsXRayTicketObservabilityRequest:
        self.function = value
        return self

    def with_iteration(self, value: int) -> ApimodelsXRayTicketObservabilityRequest:
        self.iteration = value
        return self

    def with_match_id(self, value: str) -> ApimodelsXRayTicketObservabilityRequest:
        self.match_id = value
        return self

    def with_remaining_players_per_ticket(
        self, value: List[int]
    ) -> ApimodelsXRayTicketObservabilityRequest:
        self.remaining_players_per_ticket = value
        return self

    def with_remaining_tickets(
        self, value: int
    ) -> ApimodelsXRayTicketObservabilityRequest:
        self.remaining_tickets = value
        return self

    def with_time_to_match_sec(
        self, value: float
    ) -> ApimodelsXRayTicketObservabilityRequest:
        self.time_to_match_sec = value
        return self

    def with_unbackfill_reason(
        self, value: str
    ) -> ApimodelsXRayTicketObservabilityRequest:
        self.unbackfill_reason = value
        return self

    def with_unmatch_reason(
        self, value: str
    ) -> ApimodelsXRayTicketObservabilityRequest:
        self.unmatch_reason = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "action"):
            result["action"] = str(self.action)
        elif include_empty:
            result["action"] = ""
        if hasattr(self, "game_mode"):
            result["gameMode"] = str(self.game_mode)
        elif include_empty:
            result["gameMode"] = ""
        if hasattr(self, "is_backfill_match"):
            result["isBackfillMatch"] = bool(self.is_backfill_match)
        elif include_empty:
            result["isBackfillMatch"] = False
        if hasattr(self, "is_rule_set_flexed"):
            result["isRuleSetFlexed"] = bool(self.is_rule_set_flexed)
        elif include_empty:
            result["isRuleSetFlexed"] = False
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "session_tick_id"):
            result["sessionTickID"] = str(self.session_tick_id)
        elif include_empty:
            result["sessionTickID"] = ""
        if hasattr(self, "tick_id"):
            result["tickID"] = int(self.tick_id)
        elif include_empty:
            result["tickID"] = 0
        if hasattr(self, "ticket_id"):
            result["ticketID"] = str(self.ticket_id)
        elif include_empty:
            result["ticketID"] = ""
        if hasattr(self, "timestamp"):
            result["timestamp"] = str(self.timestamp)
        elif include_empty:
            result["timestamp"] = ""
        if hasattr(self, "active_alliance_rule"):
            result["activeAllianceRule"] = self.active_alliance_rule.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["activeAllianceRule"] = ModelsAllianceRule()
        if hasattr(self, "active_matching_rule"):
            result["activeMatchingRule"] = [
                i0.to_dict(include_empty=include_empty)
                for i0 in self.active_matching_rule
            ]
        elif include_empty:
            result["activeMatchingRule"] = []
        if hasattr(self, "function"):
            result["function"] = str(self.function)
        elif include_empty:
            result["function"] = ""
        if hasattr(self, "iteration"):
            result["iteration"] = int(self.iteration)
        elif include_empty:
            result["iteration"] = 0
        if hasattr(self, "match_id"):
            result["matchID"] = str(self.match_id)
        elif include_empty:
            result["matchID"] = ""
        if hasattr(self, "remaining_players_per_ticket"):
            result["remainingPlayersPerTicket"] = [
                int(i0) for i0 in self.remaining_players_per_ticket
            ]
        elif include_empty:
            result["remainingPlayersPerTicket"] = []
        if hasattr(self, "remaining_tickets"):
            result["remainingTickets"] = int(self.remaining_tickets)
        elif include_empty:
            result["remainingTickets"] = 0
        if hasattr(self, "time_to_match_sec"):
            result["timeToMatchSec"] = float(self.time_to_match_sec)
        elif include_empty:
            result["timeToMatchSec"] = 0.0
        if hasattr(self, "unbackfill_reason"):
            result["unbackfillReason"] = str(self.unbackfill_reason)
        elif include_empty:
            result["unbackfillReason"] = ""
        if hasattr(self, "unmatch_reason"):
            result["unmatchReason"] = str(self.unmatch_reason)
        elif include_empty:
            result["unmatchReason"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        action: str,
        game_mode: str,
        is_backfill_match: bool,
        is_rule_set_flexed: bool,
        namespace: str,
        session_tick_id: str,
        tick_id: int,
        ticket_id: str,
        timestamp: str,
        active_alliance_rule: Optional[ModelsAllianceRule] = None,
        active_matching_rule: Optional[List[ModelsMatchingRule]] = None,
        function: Optional[str] = None,
        iteration: Optional[int] = None,
        match_id: Optional[str] = None,
        remaining_players_per_ticket: Optional[List[int]] = None,
        remaining_tickets: Optional[int] = None,
        time_to_match_sec: Optional[float] = None,
        unbackfill_reason: Optional[str] = None,
        unmatch_reason: Optional[str] = None,
        **kwargs,
    ) -> ApimodelsXRayTicketObservabilityRequest:
        instance = cls()
        instance.action = action
        instance.game_mode = game_mode
        instance.is_backfill_match = is_backfill_match
        instance.is_rule_set_flexed = is_rule_set_flexed
        instance.namespace = namespace
        instance.session_tick_id = session_tick_id
        instance.tick_id = tick_id
        instance.ticket_id = ticket_id
        instance.timestamp = timestamp
        if active_alliance_rule is not None:
            instance.active_alliance_rule = active_alliance_rule
        if active_matching_rule is not None:
            instance.active_matching_rule = active_matching_rule
        if function is not None:
            instance.function = function
        if iteration is not None:
            instance.iteration = iteration
        if match_id is not None:
            instance.match_id = match_id
        if remaining_players_per_ticket is not None:
            instance.remaining_players_per_ticket = remaining_players_per_ticket
        if remaining_tickets is not None:
            instance.remaining_tickets = remaining_tickets
        if time_to_match_sec is not None:
            instance.time_to_match_sec = time_to_match_sec
        if unbackfill_reason is not None:
            instance.unbackfill_reason = unbackfill_reason
        if unmatch_reason is not None:
            instance.unmatch_reason = unmatch_reason
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelsXRayTicketObservabilityRequest:
        instance = cls()
        if not dict_:
            return instance
        if "action" in dict_ and dict_["action"] is not None:
            instance.action = str(dict_["action"])
        elif include_empty:
            instance.action = ""
        if "gameMode" in dict_ and dict_["gameMode"] is not None:
            instance.game_mode = str(dict_["gameMode"])
        elif include_empty:
            instance.game_mode = ""
        if "isBackfillMatch" in dict_ and dict_["isBackfillMatch"] is not None:
            instance.is_backfill_match = bool(dict_["isBackfillMatch"])
        elif include_empty:
            instance.is_backfill_match = False
        if "isRuleSetFlexed" in dict_ and dict_["isRuleSetFlexed"] is not None:
            instance.is_rule_set_flexed = bool(dict_["isRuleSetFlexed"])
        elif include_empty:
            instance.is_rule_set_flexed = False
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "sessionTickID" in dict_ and dict_["sessionTickID"] is not None:
            instance.session_tick_id = str(dict_["sessionTickID"])
        elif include_empty:
            instance.session_tick_id = ""
        if "tickID" in dict_ and dict_["tickID"] is not None:
            instance.tick_id = int(dict_["tickID"])
        elif include_empty:
            instance.tick_id = 0
        if "ticketID" in dict_ and dict_["ticketID"] is not None:
            instance.ticket_id = str(dict_["ticketID"])
        elif include_empty:
            instance.ticket_id = ""
        if "timestamp" in dict_ and dict_["timestamp"] is not None:
            instance.timestamp = str(dict_["timestamp"])
        elif include_empty:
            instance.timestamp = ""
        if "activeAllianceRule" in dict_ and dict_["activeAllianceRule"] is not None:
            instance.active_alliance_rule = ModelsAllianceRule.create_from_dict(
                dict_["activeAllianceRule"], include_empty=include_empty
            )
        elif include_empty:
            instance.active_alliance_rule = ModelsAllianceRule()
        if "activeMatchingRule" in dict_ and dict_["activeMatchingRule"] is not None:
            instance.active_matching_rule = [
                ModelsMatchingRule.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["activeMatchingRule"]
            ]
        elif include_empty:
            instance.active_matching_rule = []
        if "function" in dict_ and dict_["function"] is not None:
            instance.function = str(dict_["function"])
        elif include_empty:
            instance.function = ""
        if "iteration" in dict_ and dict_["iteration"] is not None:
            instance.iteration = int(dict_["iteration"])
        elif include_empty:
            instance.iteration = 0
        if "matchID" in dict_ and dict_["matchID"] is not None:
            instance.match_id = str(dict_["matchID"])
        elif include_empty:
            instance.match_id = ""
        if (
            "remainingPlayersPerTicket" in dict_
            and dict_["remainingPlayersPerTicket"] is not None
        ):
            instance.remaining_players_per_ticket = [
                int(i0) for i0 in dict_["remainingPlayersPerTicket"]
            ]
        elif include_empty:
            instance.remaining_players_per_ticket = []
        if "remainingTickets" in dict_ and dict_["remainingTickets"] is not None:
            instance.remaining_tickets = int(dict_["remainingTickets"])
        elif include_empty:
            instance.remaining_tickets = 0
        if "timeToMatchSec" in dict_ and dict_["timeToMatchSec"] is not None:
            instance.time_to_match_sec = float(dict_["timeToMatchSec"])
        elif include_empty:
            instance.time_to_match_sec = 0.0
        if "unbackfillReason" in dict_ and dict_["unbackfillReason"] is not None:
            instance.unbackfill_reason = str(dict_["unbackfillReason"])
        elif include_empty:
            instance.unbackfill_reason = ""
        if "unmatchReason" in dict_ and dict_["unmatchReason"] is not None:
            instance.unmatch_reason = str(dict_["unmatchReason"])
        elif include_empty:
            instance.unmatch_reason = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelsXRayTicketObservabilityRequest]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelsXRayTicketObservabilityRequest]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelsXRayTicketObservabilityRequest,
        List[ApimodelsXRayTicketObservabilityRequest],
        Dict[Any, ApimodelsXRayTicketObservabilityRequest],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "action": "action",
            "gameMode": "game_mode",
            "isBackfillMatch": "is_backfill_match",
            "isRuleSetFlexed": "is_rule_set_flexed",
            "namespace": "namespace",
            "sessionTickID": "session_tick_id",
            "tickID": "tick_id",
            "ticketID": "ticket_id",
            "timestamp": "timestamp",
            "activeAllianceRule": "active_alliance_rule",
            "activeMatchingRule": "active_matching_rule",
            "function": "function",
            "iteration": "iteration",
            "matchID": "match_id",
            "remainingPlayersPerTicket": "remaining_players_per_ticket",
            "remainingTickets": "remaining_tickets",
            "timeToMatchSec": "time_to_match_sec",
            "unbackfillReason": "unbackfill_reason",
            "unmatchReason": "unmatch_reason",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "action": True,
            "gameMode": True,
            "isBackfillMatch": True,
            "isRuleSetFlexed": True,
            "namespace": True,
            "sessionTickID": True,
            "tickID": True,
            "ticketID": True,
            "timestamp": True,
            "activeAllianceRule": False,
            "activeMatchingRule": False,
            "function": False,
            "iteration": False,
            "matchID": False,
            "remainingPlayersPerTicket": False,
            "remainingTickets": False,
            "timeToMatchSec": False,
            "unbackfillReason": False,
            "unmatchReason": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import EnvconfigConfiguration
from ..models import LogconfigConfiguration
from ..models import ResponseError

from ..operations.config import AdminGetEnvConfig
from ..operations.config import AdminGetLogConfig
from ..operations.config import AdminPatchUpdateEnvConfig
from ..operations.config import AdminPatchUpdateLogConfig
from ..models import LogconfigConfigurationLogLevelEnum


@same_doc_as(AdminGetEnvConfig)
def admin_get_env_config(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Get Runtime Environment Variable Configuration (adminGetEnvConfig)

    Get Runtime Environment Configuration.

    Properties:
        url: /sessionhistory/v1/admin/config/env

        method: GET

        tags: ["Config"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - EnvconfigConfiguration (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)
    """
    request = AdminGetEnvConfig.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetEnvConfig)
async def admin_get_env_config_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Get Runtime Environment Variable Configuration (adminGetEnvConfig)

    Get Runtime Environment Configuration.

    Properties:
        url: /sessionhistory/v1/admin/config/env

        method: GET

        tags: ["Config"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - EnvconfigConfiguration (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)
    """
    request = AdminGetEnvConfig.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetLogConfig)
def admin_get_log_config(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Get Log Configuration (adminGetLogConfig)

    Get Log Configuration.

    Properties:
        url: /sessionhistory/v1/admin/config/log

        method: GET

        tags: ["Config"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - LogconfigConfiguration (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)
    """
    request = AdminGetLogConfig.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetLogConfig)
async def admin_get_log_config_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Get Log Configuration (adminGetLogConfig)

    Get Log Configuration.

    Properties:
        url: /sessionhistory/v1/admin/config/log

        method: GET

        tags: ["Config"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - LogconfigConfiguration (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)
    """
    request = AdminGetLogConfig.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminPatchUpdateEnvConfig)
def admin_patch_update_env_config(
    body: EnvconfigConfiguration,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Patch Update Runtime Environment Variable Configuration (adminPatchUpdateEnvConfig)

    Update Runtime Environment Variable Configuration.

    Properties:
        url: /sessionhistory/v1/admin/config/env

        method: PATCH

        tags: ["Config"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED EnvconfigConfiguration in body

    Responses:
        200: OK - EnvconfigConfiguration (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)
    """
    request = AdminPatchUpdateEnvConfig.create(
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminPatchUpdateEnvConfig)
async def admin_patch_update_env_config_async(
    body: EnvconfigConfiguration,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Patch Update Runtime Environment Variable Configuration (adminPatchUpdateEnvConfig)

    Update Runtime Environment Variable Configuration.

    Properties:
        url: /sessionhistory/v1/admin/config/env

        method: PATCH

        tags: ["Config"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED EnvconfigConfiguration in body

    Responses:
        200: OK - EnvconfigConfiguration (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)
    """
    request = AdminPatchUpdateEnvConfig.create(
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminPatchUpdateLogConfig)
def admin_patch_update_log_config(
    body: LogconfigConfiguration,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Patch Update Log Configuration (adminPatchUpdateLogConfig)

    Update Log Configuration.

    Properties:
        url: /sessionhistory/v1/admin/config/log

        method: PATCH

        tags: ["Config"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED LogconfigConfiguration in body

    Responses:
        200: OK - LogconfigConfiguration (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)
    """
    request = AdminPatchUpdateLogConfig.create(
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminPatchUpdateLogConfig)
async def admin_patch_update_log_config_async(
    body: LogconfigConfiguration,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Patch Update Log Configuration (adminPatchUpdateLogConfig)

    Update Log Configuration.

    Properties:
        url: /sessionhistory/v1/admin/config/log

        method: PATCH

        tags: ["Config"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED LogconfigConfiguration in body

    Responses:
        200: OK - LogconfigConfiguration (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)
    """
    request = AdminPatchUpdateLogConfig.create(
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Session History Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.apimodels_history import ApimodelsHistory
from ..models.models_game_session import ModelsGameSession


class ApimodelsGameSessionDetail(Model):
    """Apimodels game session detail (apimodels.GameSessionDetail)

    Properties:
        active: (active) REQUIRED bool

        created_at: (created_at) REQUIRED str

        ds_status_v2: (ds_status_v2) REQUIRED str

        ended: (ended) REQUIRED bool

        histories: (histories) REQUIRED List[ApimodelsHistory]

        joinability: (joinability) REQUIRED str

        last_data: (last_data) REQUIRED ModelsGameSession

        match_pool: (match_pool) REQUIRED str

        namespace: (namespace) REQUIRED str

        persistent: (persistent) REQUIRED bool

        pod_name: (pod_name) REQUIRED str

        session_id: (sessionID) REQUIRED str

        session_template: (session_template) REQUIRED str

        updated_at: (updated_at) REQUIRED str
    """

    # region fields

    active: bool  # REQUIRED
    created_at: str  # REQUIRED
    ds_status_v2: str  # REQUIRED
    ended: bool  # REQUIRED
    histories: List[ApimodelsHistory]  # REQUIRED
    joinability: str  # REQUIRED
    last_data: ModelsGameSession  # REQUIRED
    match_pool: str  # REQUIRED
    namespace: str  # REQUIRED
    persistent: bool  # REQUIRED
    pod_name: str  # REQUIRED
    session_id: str  # REQUIRED
    session_template: str  # REQUIRED
    updated_at: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_active(self, value: bool) -> ApimodelsGameSessionDetail:
        self.active = value
        return self

    def with_created_at(self, value: str) -> ApimodelsGameSessionDetail:
        self.created_at = value
        return self

    def with_ds_status_v2(self, value: str) -> ApimodelsGameSessionDetail:
        self.ds_status_v2 = value
        return self

    def with_ended(self, value: bool) -> ApimodelsGameSessionDetail:
        self.ended = value
        return self

    def with_histories(
        self, value: List[ApimodelsHistory]
    ) -> ApimodelsGameSessionDetail:
        self.histories = value
        return self

    def with_joinability(self, value: str) -> ApimodelsGameSessionDetail:
        self.joinability = value
        return self

    def with_last_data(self, value: ModelsGameSession) -> ApimodelsGameSessionDetail:
        self.last_data = value
        return self

    def with_match_pool(self, value: str) -> ApimodelsGameSessionDetail:
        self.match_pool = value
        return self

    def with_namespace(self, value: str) -> ApimodelsGameSessionDetail:
        self.namespace = value
        return self

    def with_persistent(self, value: bool) -> ApimodelsGameSessionDetail:
        self.persistent = value
        return self

    def with_pod_name(self, value: str) -> ApimodelsGameSessionDetail:
        self.pod_name = value
        return self

    def with_session_id(self, value: str) -> ApimodelsGameSessionDetail:
        self.session_id = value
        return self

    def with_session_template(self, value: str) -> ApimodelsGameSessionDetail:
        self.session_template = value
        return self

    def with_updated_at(self, value: str) -> ApimodelsGameSessionDetail:
        self.updated_at = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "active"):
            result["active"] = bool(self.active)
        elif include_empty:
            result["active"] = False
        if hasattr(self, "created_at"):
            result["created_at"] = str(self.created_at)
        elif include_empty:
            result["created_at"] = ""
        if hasattr(self, "ds_status_v2"):
            result["ds_status_v2"] = str(self.ds_status_v2)
        elif include_empty:
            result["ds_status_v2"] = ""
        if hasattr(self, "ended"):
            result["ended"] = bool(self.ended)
        elif include_empty:
            result["ended"] = False
        if hasattr(self, "histories"):
            result["histories"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.histories
            ]
        elif include_empty:
            result["histories"] = []
        if hasattr(self, "joinability"):
            result["joinability"] = str(self.joinability)
        elif include_empty:
            result["joinability"] = ""
        if hasattr(self, "last_data"):
            result["last_data"] = self.last_data.to_dict(include_empty=include_empty)
        elif include_empty:
            result["last_data"] = ModelsGameSession()
        if hasattr(self, "match_pool"):
            result["match_pool"] = str(self.match_pool)
        elif include_empty:
            result["match_pool"] = ""
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "persistent"):
            result["persistent"] = bool(self.persistent)
        elif include_empty:
            result["persistent"] = False
        if hasattr(self, "pod_name"):
            result["pod_name"] = str(self.pod_name)
        elif include_empty:
            result["pod_name"] = ""
        if hasattr(self, "session_id"):
            result["sessionID"] = str(self.session_id)
        elif include_empty:
            result["sessionID"] = ""
        if hasattr(self, "session_template"):
            result["session_template"] = str(self.session_template)
        elif include_empty:
            result["session_template"] = ""
        if hasattr(self, "updated_at"):
            result["updated_at"] = str(self.updated_at)
        elif include_empty:
            result["updated_at"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        active: bool,
        created_at: str,
        ds_status_v2: str,
        ended: bool,
        histories: List[ApimodelsHistory],
        joinability: str,
        last_data: ModelsGameSession,
        match_pool: str,
        namespace: str,
        persistent: bool,
        pod_name: str,
        session_id: str,
        session_template: str,
        updated_at: str,
        **kwargs,
    ) -> ApimodelsGameSessionDetail:
        instance = cls()
        instance.active = active
        instance.created_at = created_at
        instance.ds_status_v2 = ds_status_v2
        instance.ended = ended
        instance.histories = histories
        instance.joinability = joinability
        instance.last_data = last_data
        instance.match_pool = match_pool
        instance.namespace = namespace
        instance.persistent = persistent
        instance.pod_name = pod_name
        instance.session_id = session_id
        instance.session_template = session_template
        instance.updated_at = updated_at
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelsGameSessionDetail:
        instance = cls()
        if not dict_:
            return instance
        if "active" in dict_ and dict_["active"] is not None:
            instance.active = bool(dict_["active"])
        elif include_empty:
            instance.active = False
        if "created_at" in dict_ and dict_["created_at"] is not None:
            instance.created_at = str(dict_["created_at"])
        elif include_empty:
            instance.created_at = ""
        if "ds_status_v2" in dict_ and dict_["ds_status_v2"] is not None:
            instance.ds_status_v2 = str(dict_["ds_status_v2"])
        elif include_empty:
            instance.ds_status_v2 = ""
        if "ended" in dict_ and dict_["ended"] is not None:
            instance.ended = bool(dict_["ended"])
        elif include_empty:
            instance.ended = False
        if "histories" in dict_ and dict_["histories"] is not None:
            instance.histories = [
                ApimodelsHistory.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["histories"]
            ]
        elif include_empty:
            instance.histories = []
        if "joinability" in dict_ and dict_["joinability"] is not None:
            instance.joinability = str(dict_["joinability"])
        elif include_empty:
            instance.joinability = ""
        if "last_data" in dict_ and dict_["last_data"] is not None:
            instance.last_data = ModelsGameSession.create_from_dict(
                dict_["last_data"], include_empty=include_empty
            )
        elif include_empty:
            instance.last_data = ModelsGameSession()
        if "match_pool" in dict_ and dict_["match_pool"] is not None:
            instance.match_pool = str(dict_["match_pool"])
        elif include_empty:
            instance.match_pool = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "persistent" in dict_ and dict_["persistent"] is not None:
            instance.persistent = bool(dict_["persistent"])
        elif include_empty:
            instance.persistent = False
        if "pod_name" in dict_ and dict_["pod_name"] is not None:
            instance.pod_name = str(dict_["pod_name"])
        elif include_empty:
            instance.pod_name = ""
        if "sessionID" in dict_ and dict_["sessionID"] is not None:
            instance.session_id = str(dict_["sessionID"])
        elif include_empty:
            instance.session_id = ""
        if "session_template" in dict_ and dict_["session_template"] is not None:
            instance.session_template = str(dict_["session_template"])
        elif include_empty:
            instance.session_template = ""
        if "updated_at" in dict_ and dict_["updated_at"] is not None:
            instance.updated_at = str(dict_["updated_at"])
        elif include_empty:
            instance.updated_at = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelsGameSessionDetail]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelsGameSessionDetail]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelsGameSessionDetail,
        List[ApimodelsGameSessionDetail],
        Dict[Any, ApimodelsGameSessionDetail],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "active": "active",
            "created_at": "created_at",
            "ds_status_v2": "ds_status_v2",
            "ended": "ended",
            "histories": "histories",
            "joinability": "joinability",
            "last_data": "last_data",
            "match_pool": "match_pool",
            "namespace": "namespace",
            "persistent": "persistent",
            "pod_name": "pod_name",
            "sessionID": "session_id",
            "session_template": "session_template",
            "updated_at": "updated_at",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "active": True,
            "created_at": True,
            "ds_status_v2": True,
            "ended": True,
            "histories": True,
            "joinability": True,
            "last_data": True,
            "match_pool": True,
            "namespace": True,
            "persistent": True,
            "pod_name": True,
            "sessionID": True,
            "session_template": True,
            "updated_at": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session History Service."""

__version__ = "1.14.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_get_matchmaking_d_98288e import AdminGetMatchmakingDetailBySessionID
from .admin_get_matchmaking_d_8811e8 import AdminGetMatchmakingDetailByTicketID
from .admin_query_game_sessio_2eed0b import AdminQueryGameSessionDetail
from .admin_query_matchmaking_detail import AdminQueryMatchmakingDetail
from .admin_query_party_detail import AdminQueryPartyDetail
from .admin_query_ticket_detail import AdminQueryTicketDetail
from .admin_ticket_detail_get_8ac60d import AdminTicketDetailGetByTicketID
from .get_game_session_detail import GetGameSessionDetail
from .get_party_detail import GetPartyDetail
from .public_query_game_session_me import PublicQueryGameSessionMe



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import ApimodelsGameSessionDetail
from ..models import ApimodelsGameSessionDetailQueryResponse
from ..models import ApimodelsMatchmakingDetail
from ..models import ApimodelsMatchmakingDetailQueryResponse
from ..models import ApimodelsPartyDetail
from ..models import ApimodelsPartyDetailQueryResponse
from ..models import ApimodelsTicketDetailQueryResponse
from ..models import ApimodelsTicketObservabilityDetail
from ..models import ResponseError

from ..operations.game_session_detail import AdminGetMatchmakingDetailBySessionID
from ..operations.game_session_detail import AdminGetMatchmakingDetailByTicketID
from ..operations.game_session_detail import AdminQueryGameSessionDetail
from ..operations.game_session_detail import AdminQueryMatchmakingDetail
from ..operations.game_session_detail import AdminQueryPartyDetail
from ..operations.game_session_detail import AdminQueryTicketDetail
from ..operations.game_session_detail import AdminTicketDetailGetByTicketID
from ..operations.game_session_detail import GetGameSessionDetail
from ..operations.game_session_detail import GetPartyDetail
from ..operations.game_session_detail import PublicQueryGameSessionMe


@same_doc_as(AdminGetMatchmakingDetailBySessionID)
def admin_get_matchmaking_detail_by_session_id(
    session_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get detail matchmaking history by session ID. (adminGetMatchmakingDetailBySessionID)

    Get detail matchmaking history by session ID.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/matchmaking/session/{sessionId}

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

    Responses:
        200: OK - ApimodelsMatchmakingDetail (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetMatchmakingDetailBySessionID.create(
        session_id=session_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetMatchmakingDetailBySessionID)
async def admin_get_matchmaking_detail_by_session_id_async(
    session_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get detail matchmaking history by session ID. (adminGetMatchmakingDetailBySessionID)

    Get detail matchmaking history by session ID.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/matchmaking/session/{sessionId}

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

    Responses:
        200: OK - ApimodelsMatchmakingDetail (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetMatchmakingDetailBySessionID.create(
        session_id=session_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetMatchmakingDetailByTicketID)
def admin_get_matchmaking_detail_by_ticket_id(
    ticket_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get detail matchmaking history by ticket ID. (adminGetMatchmakingDetailByTicketID)

    Get detail matchmaking history by ticket ID.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/matchmaking/ticket/{ticketId}

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticket_id: (ticketId) REQUIRED str in path

    Responses:
        200: OK - ApimodelsMatchmakingDetail (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetMatchmakingDetailByTicketID.create(
        ticket_id=ticket_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetMatchmakingDetailByTicketID)
async def admin_get_matchmaking_detail_by_ticket_id_async(
    ticket_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get detail matchmaking history by ticket ID. (adminGetMatchmakingDetailByTicketID)

    Get detail matchmaking history by ticket ID.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/matchmaking/ticket/{ticketId}

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticket_id: (ticketId) REQUIRED str in path

    Responses:
        200: OK - ApimodelsMatchmakingDetail (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetMatchmakingDetailByTicketID.create(
        ticket_id=ticket_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminQueryGameSessionDetail)
def admin_query_game_session_detail(
    completed_only: Optional[str] = None,
    configuration_name: Optional[str] = None,
    ds_pod_name: Optional[str] = None,
    end_date: Optional[str] = None,
    game_session_id: Optional[str] = None,
    is_persistent: Optional[str] = None,
    joinability: Optional[str] = None,
    limit: Optional[int] = None,
    match_pool: Optional[str] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    order_by: Optional[str] = None,
    start_date: Optional[str] = None,
    status_v2: Optional[str] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all game sessions history. (adminQueryGameSessionDetail)

    Get all game sessions.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/gamesessions

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        completed_only: (completedOnly) OPTIONAL str in query

        configuration_name: (configurationName) OPTIONAL str in query

        ds_pod_name: (dsPodName) OPTIONAL str in query

        end_date: (endDate) OPTIONAL str in query

        game_session_id: (gameSessionID) OPTIONAL str in query

        is_persistent: (isPersistent) OPTIONAL str in query

        joinability: (joinability) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        match_pool: (matchPool) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        order_by: (orderBy) OPTIONAL str in query

        start_date: (startDate) OPTIONAL str in query

        status_v2: (statusV2) OPTIONAL str in query

        user_id: (userID) OPTIONAL str in query

    Responses:
        200: OK - ApimodelsGameSessionDetailQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminQueryGameSessionDetail.create(
        completed_only=completed_only,
        configuration_name=configuration_name,
        ds_pod_name=ds_pod_name,
        end_date=end_date,
        game_session_id=game_session_id,
        is_persistent=is_persistent,
        joinability=joinability,
        limit=limit,
        match_pool=match_pool,
        offset=offset,
        order=order,
        order_by=order_by,
        start_date=start_date,
        status_v2=status_v2,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminQueryGameSessionDetail)
async def admin_query_game_session_detail_async(
    completed_only: Optional[str] = None,
    configuration_name: Optional[str] = None,
    ds_pod_name: Optional[str] = None,
    end_date: Optional[str] = None,
    game_session_id: Optional[str] = None,
    is_persistent: Optional[str] = None,
    joinability: Optional[str] = None,
    limit: Optional[int] = None,
    match_pool: Optional[str] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    order_by: Optional[str] = None,
    start_date: Optional[str] = None,
    status_v2: Optional[str] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all game sessions history. (adminQueryGameSessionDetail)

    Get all game sessions.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/gamesessions

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        completed_only: (completedOnly) OPTIONAL str in query

        configuration_name: (configurationName) OPTIONAL str in query

        ds_pod_name: (dsPodName) OPTIONAL str in query

        end_date: (endDate) OPTIONAL str in query

        game_session_id: (gameSessionID) OPTIONAL str in query

        is_persistent: (isPersistent) OPTIONAL str in query

        joinability: (joinability) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        match_pool: (matchPool) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        order_by: (orderBy) OPTIONAL str in query

        start_date: (startDate) OPTIONAL str in query

        status_v2: (statusV2) OPTIONAL str in query

        user_id: (userID) OPTIONAL str in query

    Responses:
        200: OK - ApimodelsGameSessionDetailQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminQueryGameSessionDetail.create(
        completed_only=completed_only,
        configuration_name=configuration_name,
        ds_pod_name=ds_pod_name,
        end_date=end_date,
        game_session_id=game_session_id,
        is_persistent=is_persistent,
        joinability=joinability,
        limit=limit,
        match_pool=match_pool,
        offset=offset,
        order=order,
        order_by=order_by,
        start_date=start_date,
        status_v2=status_v2,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminQueryMatchmakingDetail)
def admin_query_matchmaking_detail(
    game_session_id: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    order_by: Optional[str] = None,
    ticket_id: Optional[str] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all matchmaking history. (adminQueryMatchmakingDetail)

    Get all matchmaking.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/matchmaking

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        game_session_id: (gameSessionID) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        order_by: (orderBy) OPTIONAL str in query

        ticket_id: (ticketID) OPTIONAL str in query

        user_id: (userID) OPTIONAL str in query

    Responses:
        200: OK - ApimodelsMatchmakingDetailQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminQueryMatchmakingDetail.create(
        game_session_id=game_session_id,
        limit=limit,
        offset=offset,
        order=order,
        order_by=order_by,
        ticket_id=ticket_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminQueryMatchmakingDetail)
async def admin_query_matchmaking_detail_async(
    game_session_id: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    order_by: Optional[str] = None,
    ticket_id: Optional[str] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all matchmaking history. (adminQueryMatchmakingDetail)

    Get all matchmaking.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/matchmaking

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        game_session_id: (gameSessionID) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        order_by: (orderBy) OPTIONAL str in query

        ticket_id: (ticketID) OPTIONAL str in query

        user_id: (userID) OPTIONAL str in query

    Responses:
        200: OK - ApimodelsMatchmakingDetailQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminQueryMatchmakingDetail.create(
        game_session_id=game_session_id,
        limit=limit,
        offset=offset,
        order=order,
        order_by=order_by,
        ticket_id=ticket_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminQueryPartyDetail)
def admin_query_party_detail(
    end_date: Optional[str] = None,
    joinability: Optional[str] = None,
    leader_id: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    order_by: Optional[str] = None,
    party_id: Optional[str] = None,
    start_date: Optional[str] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all parties history. (adminQueryPartyDetail)

    Get all parties.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/parties

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) OPTIONAL str in query

        joinability: (joinability) OPTIONAL str in query

        leader_id: (leaderID) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        order_by: (orderBy) OPTIONAL str in query

        party_id: (partyID) OPTIONAL str in query

        start_date: (startDate) OPTIONAL str in query

        user_id: (userID) OPTIONAL str in query

    Responses:
        200: OK - ApimodelsPartyDetailQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminQueryPartyDetail.create(
        end_date=end_date,
        joinability=joinability,
        leader_id=leader_id,
        limit=limit,
        offset=offset,
        order=order,
        order_by=order_by,
        party_id=party_id,
        start_date=start_date,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminQueryPartyDetail)
async def admin_query_party_detail_async(
    end_date: Optional[str] = None,
    joinability: Optional[str] = None,
    leader_id: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    order_by: Optional[str] = None,
    party_id: Optional[str] = None,
    start_date: Optional[str] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all parties history. (adminQueryPartyDetail)

    Get all parties.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/parties

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) OPTIONAL str in query

        joinability: (joinability) OPTIONAL str in query

        leader_id: (leaderID) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        order_by: (orderBy) OPTIONAL str in query

        party_id: (partyID) OPTIONAL str in query

        start_date: (startDate) OPTIONAL str in query

        user_id: (userID) OPTIONAL str in query

    Responses:
        200: OK - ApimodelsPartyDetailQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminQueryPartyDetail.create(
        end_date=end_date,
        joinability=joinability,
        leader_id=leader_id,
        limit=limit,
        offset=offset,
        order=order,
        order_by=order_by,
        party_id=party_id,
        start_date=start_date,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminQueryTicketDetail)
def admin_query_ticket_detail(
    end_date: Optional[str] = None,
    game_mode: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    party_id: Optional[str] = None,
    region: Optional[str] = None,
    start_date: Optional[str] = None,
    user_i_ds: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all matchmaking ticket history. (adminQueryTicketDetail)

    Get all matchmaking ticket.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/tickets

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) OPTIONAL str in query

        game_mode: (gameMode) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        party_id: (partyID) OPTIONAL str in query

        region: (region) OPTIONAL str in query

        start_date: (startDate) OPTIONAL str in query

        user_i_ds: (userIDs) OPTIONAL str in query

    Responses:
        200: OK - ApimodelsTicketDetailQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminQueryTicketDetail.create(
        end_date=end_date,
        game_mode=game_mode,
        limit=limit,
        offset=offset,
        order=order,
        party_id=party_id,
        region=region,
        start_date=start_date,
        user_i_ds=user_i_ds,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminQueryTicketDetail)
async def admin_query_ticket_detail_async(
    end_date: Optional[str] = None,
    game_mode: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    party_id: Optional[str] = None,
    region: Optional[str] = None,
    start_date: Optional[str] = None,
    user_i_ds: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all matchmaking ticket history. (adminQueryTicketDetail)

    Get all matchmaking ticket.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/tickets

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) OPTIONAL str in query

        game_mode: (gameMode) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        party_id: (partyID) OPTIONAL str in query

        region: (region) OPTIONAL str in query

        start_date: (startDate) OPTIONAL str in query

        user_i_ds: (userIDs) OPTIONAL str in query

    Responses:
        200: OK - ApimodelsTicketDetailQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminQueryTicketDetail.create(
        end_date=end_date,
        game_mode=game_mode,
        limit=limit,
        offset=offset,
        order=order,
        party_id=party_id,
        region=region,
        start_date=start_date,
        user_i_ds=user_i_ds,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminTicketDetailGetByTicketID)
def admin_ticket_detail_get_by_ticket_id(
    ticket_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get detail matchmaking ticket history by ticket ID. (adminTicketDetailGetByTicketID)

    Get detail matchmaking ticket history by ticket ID.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/tickets/{ticketId}

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticket_id: (ticketId) REQUIRED str in path

    Responses:
        200: OK - ApimodelsTicketObservabilityDetail (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminTicketDetailGetByTicketID.create(
        ticket_id=ticket_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminTicketDetailGetByTicketID)
async def admin_ticket_detail_get_by_ticket_id_async(
    ticket_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get detail matchmaking ticket history by ticket ID. (adminTicketDetailGetByTicketID)

    Get detail matchmaking ticket history by ticket ID.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/tickets/{ticketId}

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticket_id: (ticketId) REQUIRED str in path

    Responses:
        200: OK - ApimodelsTicketObservabilityDetail (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminTicketDetailGetByTicketID.create(
        ticket_id=ticket_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetGameSessionDetail)
def get_game_session_detail(
    session_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get game session detail. (getGameSessionDetail)

    Get game session detail.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/gamesessions/{sessionId}

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

    Responses:
        200: OK - ApimodelsGameSessionDetail (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetGameSessionDetail.create(
        session_id=session_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetGameSessionDetail)
async def get_game_session_detail_async(
    session_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get game session detail. (getGameSessionDetail)

    Get game session detail.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/gamesessions/{sessionId}

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

    Responses:
        200: OK - ApimodelsGameSessionDetail (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetGameSessionDetail.create(
        session_id=session_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetPartyDetail)
def get_party_detail(
    session_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get party detail. (getPartyDetail)

    Get party detail.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/parties/{sessionId}

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

    Responses:
        200: OK - ApimodelsPartyDetail (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetPartyDetail.create(
        session_id=session_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetPartyDetail)
async def get_party_detail_async(
    session_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get party detail. (getPartyDetail)

    Get party detail.

    Properties:
        url: /sessionhistory/v1/admin/namespaces/{namespace}/parties/{sessionId}

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

    Responses:
        200: OK - ApimodelsPartyDetail (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetPartyDetail.create(
        session_id=session_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicQueryGameSessionMe)
def public_query_game_session_me(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all game sessions history for current user. (publicQueryGameSessionMe)

    Get all game sessions history for current user.

    Properties:
        url: /sessionhistory/v1/public/namespaces/{namespace}/users/me/gamesessions

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

    Responses:
        200: OK - ApimodelsGameSessionDetailQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        429: Too Many Requests - ResponseError (Too Many Requests)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicQueryGameSessionMe.create(
        limit=limit,
        offset=offset,
        order=order,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicQueryGameSessionMe)
async def public_query_game_session_me_async(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all game sessions history for current user. (publicQueryGameSessionMe)

    Get all game sessions history for current user.

    Properties:
        url: /sessionhistory/v1/public/namespaces/{namespace}/users/me/gamesessions

        method: GET

        tags: ["Game Session Detail"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

    Responses:
        200: OK - ApimodelsGameSessionDetailQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        429: Too Many Requests - ResponseError (Too Many Requests)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicQueryGameSessionMe.create(
        limit=limit,
        offset=offset,
        order=order,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )
